Core
====

.. automodule:: mumott.core

.. index::
   single: Class reference; IntegralTransformer

ProjectionParameters
--------------------

.. autoclass:: mumott.core.ProjectionParameters
   :members:
   :undoc-members:


.. index::
   single: Class reference; SimulatedDataGenerator

SimulatedDataGenerator
----------------------

.. autoclass:: mumott.core.SimulatedDataGenerator
   :members:
   :undoc-members:


.. index::
   single: Class reference; SphericalHarmonicMapper

SphericalHarmonicMapper
-----------------------

.. autoclass:: mumott.core.SphericalHarmonicMapper
   :members:
   :undoc-members:

.. index::
   single: Module reference; john_transform

john_transform
--------------

.. automodule:: mumott.core.john_transform
   :members: